OC.L10N.register(
    "viewer",
    {
    "Viewer" : "查看器",
    "Simple file viewer with slideshow for media" : "带媒体幻灯片的简单文件查看器",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "像电影一样展示您最新的假日照片和视频，直接在您的 Nextcloud 中浏览您最新的小说，借助您收藏文件的直接预览选择您专辑最佳的 GIF，还有更多！",
    "Your browser does not support audio." : "您的浏览器不支持音频。",
    "Error loading {name}" : "加载 {name} 出错",
    "Unsaved changes" : "未保存的更改",
    "Your browser does not support videos." : "您的浏览器不支持视频。",
    "Edit" : "编辑",
    "Open sidebar" : "打开侧边栏",
    "Download" : "下载",
    "Delete" : "删除",
    "There is no plugin available to display this file type" : "没有可用于显示此文件类型的插件",
    "View" : "查看",
    "Name" : "名称",
    "Save" : "保存",
    "Back" : "返回",
    "Loading …" : "正在加载 …",
    "Reset" : "重置",
    "Cancel" : "取消",
    "Continue" : "继续",
    "Undo" : "撤销操作",
    "Redo" : "恢复上个操作",
    "Zoom in" : "放大",
    "Original" : "原图",
    "Custom" : "自定义",
    "Value" : "值",
    "Image" : "图片",
    "Line" : "线段",
    "Text" : "文本 ",
    "Size" : "尺寸",
    "Position" : "位置",
    "Extension" : "扩展",
    "Name is required." : "名称是必填项。",
    "Quality" : "质量"
},
"nplurals=1; plural=0;");
